==> adsprod-facade-2.5.16.1-sources.jar: com/bxm/adsprod/facade/award/OutSideDto.java <==
package com.bxm.adsprod.facade.award;

import java.io.Serializable;

/**
 * 外投Dto
 *
 * @ClassName OutSideDto
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/8/13 18:35
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/8/13 18:35
 **/
public class OutSideDto implements Serializable{

    private static final long serialVersionUID = 6530312733950425043L;

    private String assetId;

    private String ipaddress;

    private  String isSupplement;

    /**
     * 是否使用JS跳转
     */
    private boolean js;

    /**
     * 广告位ID
     */
    private  String positionId;
    /**
     * 用户uid
     */
    private  String uid;
    /**
     * 微信 1 or 非微信 0
     */
    private  Integer ua;

    /**
     * 活动ID
     */
    private  String activityId;

    public String getAssetId() {
        return assetId;
    }

    public void setAssetId(String assetId) {
        this.assetId = assetId;
    }

    public String getIpaddress() {
        return ipaddress;
    }

    public String getIsSupplement() {
        return isSupplement;
    }

    public void setIsSupplement(String isSupplement) {
        this.isSupplement = isSupplement;
    }

    public void setIpaddress(String ipaddress) {
        this.ipaddress = ipaddress;
    }

    public boolean isJs() {
        return js;
    }

    public void setJs(boolean js) {
        this.js = js;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getUa() {
        return ua;
    }

    public void setUa(Integer ua) {
        this.ua = ua;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }
}

==> adsprod-facade-3.3.6.15-sources.jar: com/bxm/adsprod/facade/award/OutSideDto.java <==
package com.bxm.adsprod.facade.award;

import java.io.Serializable;

/**
 * 外投Dto
 *
 * @ClassName OutSideDto
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/8/13 18:35
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/8/13 18:35
 **/
public class OutSideDto implements Serializable{

    private static final long serialVersionUID = 6530312733950425043L;

    private String assetId;

    private String ipaddress;

    private  String isSupplement;

    /**
     * 是否使用JS跳转
     */
    private boolean js;

    /**
     * 广告位ID
     */
    private  String positionId;
    /**
     * 用户uid
     */
    private  String uid;
    /**
     * 微信 1 or 非微信 0
     */
    private  Integer ua;

    /**
     * 活动ID
     */
    private  String activityId;
    /**
     * spm</br>
     * abe会传bdid的值过来
     */
    private String spm;

    public String getAssetId() {
        return assetId;
    }

    public void setAssetId(String assetId) {
        this.assetId = assetId;
    }

    public String getIpaddress() {
        return ipaddress;
    }

    public String getIsSupplement() {
        return isSupplement;
    }

    public void setIsSupplement(String isSupplement) {
        this.isSupplement = isSupplement;
    }

    public void setIpaddress(String ipaddress) {
        this.ipaddress = ipaddress;
    }

    public boolean isJs() {
        return js;
    }

    public void setJs(boolean js) {
        this.js = js;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public Integer getUa() {
        return ua;
    }

    public void setUa(Integer ua) {
        this.ua = ua;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getSpm() {
        return spm;
    }

    public void setSpm(String spm) {
        this.spm = spm;
    }
}
